# Iflearner Flow Client
Interactive tools for `Iflearner Flow`, including `flow sdk` and `flow cli`

### Installation
You can execute the following command to quickly install:
```shell
pip install iflearner-flow-client
```
After the installation is complete, you can refer to the sdk package for interface calls,
and you can also directly use the compiled cli tools `flow_federate_cli` and `flow_server_cli` to operate.

## Usage tutorial
### SDK
- [Flow Server SDK](https://iflytek.github.io/iflearner-flow/api/flow_server_sdk)
- [Flow Federate SDK](https://iflytek.github.io/iflearner-flow/api/flow_federate_sdk)

### CLI
- [Flow Server CLI](https://iflytek.github.io/iflearner-flow/api/flow_server_cli)
- [Flow Federate CLI](https://iflytek.github.io/iflearner-flow/api/flow_federate_cli)